@@ -2,7 +2,7 @@ package DateTimeX::Format::Excel;
 BEGIN {
   $DateTimeX::Format::Excel::AUTHORITY = 'cpan:JANDREW';
 }
-use version 0.9909; our $VERSION = version->declare("v0.12.14");
+use version; our $VERSION = version->declare("v0.12.16");
 use	5.010;
 use	strict;
 use	warnings;
@@ -18,7 +18,7 @@ if( $ENV{ Smart_Comments } ){
 	### Smart-Comments turned on for DateTimeX-Format-Excel ...
 }
 use	lib	'../../../lib',;
-use DateTimeX::Format::Excel::Types v0.12 qw(
+use DateTimeX::Format::Excel::Types 0.012 qw(
 	DateTimeHash
 	DateTimeInstance
 	HashToDateTime
@@ -467,7 +467,7 @@ This software is copyrighted (c) 2014 by Jed Lund
 
 B<5.010> - (L<perl>)
 
-L<version>
+L<version> - 0.9909
 
 L<Moose>
 
